@@ -104,8 +104,7 @@ class NaomiRom:
         # TODO: Support encrypted ROM headers. For now, we don't support this so we check
         # the encryption flag and state that the ROM isn't valid if it is set.
         return (
-            self.data[0x000:0x010] in {b'NAOMI           ', b'Naomi2          '} and
-            self.data[0x4FF] == 0xFF
+            self.data[0x000:0x010] in {b'NAOMI           ', b'Naomi2          '} and self.data[0x4FF] == 0xFF
         )
 
     def _raise_on_invalid(self) -> None:
